- Issues not following the template may be closed for that reason alone.
- **Operating system and version**:
- **Python version**:
- **Fauxmo version** (`fauxmo --version`):
- **Echo device type** (e.g. Echo, Echo Plus, Dot): 
- **[Echo Firmware Version](https://github.com/n8henrie/fauxmo/blob/dev/README.md#troubleshooting--faq)**: 

## My Issue



## [WHYT](http://mattgemmell.com/what-have-you-tried)



---

Please make sure you've taken these steps before submitting a new issue:

- [ ] Try to reproduce the issue with Fauxmo installed in a
  [venv](https://docs.python.org/3/library/venv.html)
- [ ] Ensure you're running a supported version of Python
    - Requires Python >= 3.2 for Fauxmo < 0.3.0
    - Requires Python >= 3.4.4 for Fauxmo >= 0.3.0
    - Requires Python >= 3.6.0 for Fauxmo >= 0.4.0
- [ ] Run Fauxmo in debug mode (`-vvv`) and include relevant output
- [ ] Include your Fauxmo `config.json`
- [ ] Search the existing (including closed) issues
- [ ] Please use [codeblocks][1] around your debug output and config

[1]: https://help.github.com/articles/creating-and-highlighting-code-blocks/
